@@ -25,10 +25,21 @@ evas_object_new(Evas *e __UNUSED__)
    obj->magic = MAGIC_OBJ;
    obj->cur.scale = 1.0;
    obj->prev.scale = 1.0;
+   obj->is_frame = EINA_FALSE;
 
    return obj;
 }
 
+void
+evas_object_change_reset(Evas_Object *obj)
+{
+   obj->changed = EINA_FALSE;
+   obj->changed_move = EINA_FALSE;
+   obj->changed_color = EINA_FALSE;
+   obj->changed_map = EINA_FALSE;
+   obj->changed_pchange = EINA_FALSE;
+}
+
 void
 evas_object_free(Evas_Object *obj, int clean_layer)
 {
@@ -71,35 +82,25 @@ evas_object_change(Evas_Object *obj)
 {
    Eina_List *l;
    Evas_Object *obj2;
-   Eina_Bool movch = 0;
+   Eina_Bool movch = EINA_FALSE;
+
+   if (obj->layer->evas->nochange) return;
+   obj->layer->evas->changed = EINA_TRUE;
 
-   if (obj->layer->evas->nochange)
-     {
-//        printf("nochange %p\n", obj);
-        return;
-     }
-//   else
-//      printf("ch %p\n", obj);
-   obj->layer->evas->changed = 1;
    if (obj->changed_move)
      {
-        movch = 1;
-        obj->changed_move = 0;
-        if (!obj->changed_nomove) obj->changed_move_only = 1;
-        if (obj->changed) return;
+        movch = EINA_TRUE;
+        obj->changed_move = EINA_FALSE;
      }
-   else
-     {
-        obj->changed_move_only = 0;
-        obj->changed_nomove = 1;
-        if (obj->changed) return;
-     }
-//   obj->changed = 1;
+
+     if (obj->changed) return;
+
    evas_render_object_recalc(obj);
    /* set changed flag on all objects this one clips too */
    if (!((movch) && (obj->is_static_clip)))
      {
-        EINA_LIST_FOREACH(obj->clip.clipees, l, obj2) evas_object_change(obj2);
+        EINA_LIST_FOREACH(obj->clip.clipees, l, obj2)
+          evas_object_change(obj2);
      }
    EINA_LIST_FOREACH(obj->proxy.proxies, l, obj2)
      {
@@ -111,8 +112,8 @@ evas_object_change(Evas_Object *obj)
 void
 evas_object_render_pre_visible_change(Eina_Array *rects, Evas_Object *obj, int is_v, int was_v)
 {
-   if (obj->smart.smart) return ;
-   if (is_v == was_v) return ;
+   if (obj->smart.smart) return;
+   if (is_v == was_v) return;
    if (is_v)
      {
         evas_add_rect(rects,
@@ -134,8 +135,8 @@ evas_object_render_pre_visible_change(Eina_Array *rects, Evas_Object *obj, int i
 void
 evas_object_render_pre_clipper_change(Eina_Array *rects, Evas_Object *obj)
 {
-   if (obj->smart.smart) return ;
-   if (obj->cur.clipper == obj->prev.clipper) return ;
+   if (obj->smart.smart) return;
+   if (obj->cur.clipper == obj->prev.clipper) return;
    if ((obj->cur.clipper) && (obj->prev.clipper))
      {
         /* get difference rects between clippers */
@@ -196,7 +197,7 @@ evas_object_render_pre_prev_cur_add(Eina_Array *rects, Evas_Object *obj)
                  obj->prev.cache.clip.y,
                  obj->prev.cache.clip.w,
                  obj->prev.cache.clip.h);
-/*        
+/*
         evas_add_rect(rects,
                       obj->cur.geometry.x,
                       obj->cur.geometry.y,
@@ -223,11 +224,12 @@ evas_object_clip_changes_clean(Evas_Object *obj)
 {
    Eina_Rectangle *r;
 
-   EINA_LIST_FREE(obj->clip.changes, r) eina_rectangle_free(r);
+   EINA_LIST_FREE(obj->clip.changes, r)
+     eina_rectangle_free(r);
 }
 
 void
-evas_object_render_pre_effect_updates(Eina_Array *rects, Evas_Object *obj, int is_v, int was_v)
+evas_object_render_pre_effect_updates(Eina_Array *rects, Evas_Object *obj, int is_v, int was_v __UNUSED__)
 {
    Eina_Rectangle *r;
    Evas_Object *clipper;
@@ -238,7 +240,6 @@ evas_object_render_pre_effect_updates(Eina_Array *rects, Evas_Object *obj, int i
 
    if (obj->smart.smart) goto end;
    /* FIXME: was_v isn't used... why? */
-   was_v = 0;
    if (!obj->clip.clipees)
      {
         EINA_ARRAY_ITER_NEXT(rects, i, r, it)
@@ -370,7 +371,6 @@ evas_object_ref(Evas_Object *obj)
    return;
    MAGIC_CHECK_END();
    obj->ref++;
-   if (obj->ref == 0) obj->ref--;
 }
 
 EAPI void
@@ -384,6 +384,15 @@ evas_object_unref(Evas_Object *obj)
    if ((obj->del_ref) && (obj->ref == 0)) evas_object_del(obj);
 }
 
+EAPI int
+evas_object_ref_get(const Evas_Object *obj)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   return 0;
+   MAGIC_CHECK_END();
+   return obj->ref;
+}
+
 EAPI void
 evas_object_del(Evas_Object *obj)
 {
@@ -395,7 +404,7 @@ evas_object_del(Evas_Object *obj)
 
    if (obj->ref > 0)
      {
-        obj->del_ref = 1;
+        obj->del_ref = EINA_TRUE;
         return;
      }
 #ifdef EVAS_FRAME_QUEUING
@@ -405,14 +414,14 @@ evas_object_del(Evas_Object *obj)
    evas_object_hide(obj);
    if (obj->focused)
      {
-        obj->focused = 0;
+        obj->focused = EINA_FALSE;
         obj->layer->evas->focused = NULL;
         _evas_object_event_new();
-        evas_object_event_callback_call(obj, EVAS_CALLBACK_FOCUS_OUT, NULL);
+        evas_object_event_callback_call(obj, EVAS_CALLBACK_FOCUS_OUT, NULL, _evas_event_counter);
         _evas_post_event_callback_call(obj->layer->evas);
      }
    _evas_object_event_new();
-   evas_object_event_callback_call(obj, EVAS_CALLBACK_DEL, NULL);
+   evas_object_event_callback_call(obj, EVAS_CALLBACK_DEL, NULL, _evas_event_counter);
    _evas_post_event_callback_call(obj->layer->evas);
    if (obj->mouse_grabbed > 0)
       obj->layer->evas->pointer.mouse_grabbed -= obj->mouse_grabbed;
@@ -426,9 +435,6 @@ evas_object_del(Evas_Object *obj)
         evas_object_free(obj, 1);
         return;
      }
-   obj->layer->evas->pointer.mouse_grabbed -= obj->mouse_grabbed;
-   obj->mouse_grabbed = 0;
-   obj->mouse_in = 0;
    evas_object_grabs_cleanup(obj);
    while (obj->clip.clipees)
      evas_object_clip_unset(obj->clip.clipees->data);
@@ -438,7 +444,7 @@ evas_object_del(Evas_Object *obj)
    if (obj->smart.smart) evas_object_smart_del(obj);
    evas_object_map_set(obj, NULL);
    _evas_object_event_new();
-   evas_object_event_callback_call(obj, EVAS_CALLBACK_FREE, NULL);
+   evas_object_event_callback_call(obj, EVAS_CALLBACK_FREE, NULL, _evas_event_counter);
    _evas_post_event_callback_call(obj->layer->evas);
    evas_object_smart_cleanup(obj);
    obj->delete_me = 1;
@@ -449,18 +455,38 @@ EAPI void
 evas_object_move(Evas_Object *obj, Evas_Coord x, Evas_Coord y)
 {
    int is, was = 0, pass = 0, freeze = 0;
+   int nx = 0, ny = 0;
 
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
    return;
    MAGIC_CHECK_END();
    if (obj->delete_me) return;
-   if (evas_object_intercept_call_move(obj, x, y)) return;
+
+   nx = x;
+   ny = y;
+
+   if (!obj->is_frame)
+     {
+        int fx, fy;
+
+        evas_output_framespace_get(obj->layer->evas, &fx, &fy, NULL, NULL);
+        if (!obj->smart.parent)
+          {
+             nx += fx;
+             ny += fy;
+          }
+     }
+
+   if (evas_object_intercept_call_move(obj, nx, ny)) return;
+
    if (obj->doing.in_move > 0)
      {
         WRN("evas_object_move() called on object %p when in the middle of moving the same object", obj);
         return;
      }
-   if ((obj->cur.geometry.x == x) && (obj->cur.geometry.y == y)) return;
+
+   if ((obj->cur.geometry.x == nx) && (obj->cur.geometry.y == ny)) return;
+
    if (obj->layer->evas->events_frozen <= 0)
      {
         pass = evas_event_passes_through(obj);
@@ -471,15 +497,18 @@ evas_object_move(Evas_Object *obj, Evas_Coord x, Evas_Coord y)
                                               obj->layer->evas->pointer.y, 1, 1);
      }
    obj->doing.in_move++;
+
    if (obj->smart.smart)
      {
         if (obj->smart.smart->smart_class->move)
-          obj->smart.smart->smart_class->move(obj, x, y);
+          obj->smart.smart->smart_class->move(obj, nx, ny);
      }
-   obj->cur.geometry.x = x;
-   obj->cur.geometry.y = y;
+
+   obj->cur.geometry.x = nx;
+   obj->cur.geometry.y = ny;
+
 ////   obj->cur.cache.geometry.validity = 0;
-   obj->changed_move = 1;
+   obj->changed_move = EINA_TRUE;
    evas_object_change(obj);
    evas_object_clip_dirty(obj);
    obj->doing.in_move--;
@@ -509,19 +538,40 @@ EAPI void
 evas_object_resize(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
 {
    int is, was = 0, pass = 0, freeze =0;
+   int nw = 0, nh = 0;
 
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
    return;
    MAGIC_CHECK_END();
    if (obj->delete_me) return;
    if (w < 0) w = 0; if (h < 0) h = 0;
-   if (evas_object_intercept_call_resize(obj, w, h)) return;
+
+   nw = w;
+   nh = h;
+   if (!obj->is_frame)
+     {
+        int fw, fh;
+
+        evas_output_framespace_get(obj->layer->evas, NULL, NULL, &fw, &fh);
+        if (!obj->smart.parent)
+          {
+             nw = w - fw;
+             nh = h - fh;
+             if (nw < 0) nw = 0;
+             if (nh < 0) nh = 0;
+          }
+     }
+
+   if (evas_object_intercept_call_resize(obj, nw, nh)) return;
+
    if (obj->doing.in_resize > 0)
      {
         WRN("evas_object_resize() called on object %p when in the middle of resizing the same object", obj);
         return;
      }
-   if ((obj->cur.geometry.w == w) && (obj->cur.geometry.h == h)) return;
+
+   if ((obj->cur.geometry.w == nw) && (obj->cur.geometry.h == nh)) return;
+
    if (obj->layer->evas->events_frozen <= 0)
      {
         pass = evas_event_passes_through(obj);
@@ -532,13 +582,16 @@ evas_object_resize(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
                                               obj->layer->evas->pointer.y, 1, 1);
      }
    obj->doing.in_resize++;
+
    if (obj->smart.smart)
      {
        if (obj->smart.smart->smart_class->resize)
-         obj->smart.smart->smart_class->resize(obj, w, h);
+          obj->smart.smart->smart_class->resize(obj, nw, nh);
      }
-   obj->cur.geometry.w = w;
-   obj->cur.geometry.h = h;
+
+   obj->cur.geometry.w = nw;
+   obj->cur.geometry.h = nh;
+
 ////   obj->cur.cache.geometry.validity = 0;
    evas_object_change(obj);
    evas_object_clip_dirty(obj);
@@ -581,6 +634,7 @@ evas_object_geometry_get(const Evas_Object *obj, Evas_Coord *x, Evas_Coord *y, E
         if (x) *x = 0; if (y) *y = 0; if (w) *w = 0; if (h) *h = 0;
         return;
      }
+
    if (x) *x = obj->cur.geometry.x;
    if (y) *y = obj->cur.geometry.y;
    if (w) *w = obj->cur.geometry.w;
@@ -961,7 +1015,7 @@ evas_object_hide(Evas_Object *obj)
      }
    else
      {
-/*        
+/*
         if (obj->mouse_grabbed > 0)
           obj->layer->evas->pointer.mouse_grabbed -= obj->mouse_grabbed;
         if ((obj->mouse_in) || (obj->mouse_grabbed > 0))
@@ -994,6 +1048,22 @@ evas_object_color_set(Evas_Object *obj, int r, int g, int b, int a)
    if (g > 255) g = 255; if (g < 0) g = 0;
    if (b > 255) b = 255; if (b < 0) b = 0;
    if (a > 255) a = 255; if (a < 0) a = 0;
+   if (r > a)
+     {
+        r = a;
+        ERR("Evas only handles pre multiplied colors!");
+     }
+   if (g > a)
+     {
+        g = a;
+        ERR("Evas only handles pre multiplied colors!");
+     }
+   if (b > a)
+     {
+        b = a;
+        ERR("Evas only handles pre multiplied colors!");
+     }
+
    if (evas_object_intercept_call_color_set(obj, r, g, b, a)) return;
    if (obj->smart.smart)
      {
@@ -1008,8 +1078,10 @@ evas_object_color_set(Evas_Object *obj, int r, int g, int b, int a)
    obj->cur.color.g = g;
    obj->cur.color.b = b;
    evas_object_clip_dirty(obj);
+
    if ((obj->cur.color.a == 0) && (a == 0) && (obj->cur.render_op == EVAS_RENDER_BLEND)) return;
    obj->cur.color.a = a;
+   obj->changed_color = EINA_TRUE;
    evas_object_change(obj);
 }
 
@@ -1084,8 +1156,7 @@ evas_object_render_op_set(Evas_Object *obj, Evas_Render_Op render_op)
    return;
    MAGIC_CHECK_END();
    if (obj->delete_me) return;
-   if ((Evas_Render_Op)obj->cur.render_op == render_op)
-      return;
+   if (obj->cur.render_op == render_op) return;
    obj->cur.render_op = render_op;
    evas_object_change(obj);
 }
@@ -1317,3 +1388,20 @@ evas_object_static_clip_get(const Evas_Object *obj)
    return obj->is_static_clip;
 }
 
+EAPI void
+evas_object_is_frame_object_set(Evas_Object *obj, Eina_Bool is_frame)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   return;
+   MAGIC_CHECK_END();
+   obj->is_frame = is_frame;
+}
+
+EAPI Eina_Bool
+evas_object_is_frame_object_get(Evas_Object *obj)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   return EINA_FALSE;
+   MAGIC_CHECK_END();
+   return obj->is_frame;
+}
