@@ -238,7 +238,7 @@ static Evas_Coord
 _evas_object_text_horiz_advance_get(const Evas_Object *obj,
       const Evas_Object_Text *o)
 {
-   Evas_Object_Text_Item *it;
+   Evas_Object_Text_Item *it, *last_it = NULL;
    Evas_Coord adv;
    (void) obj;
 
@@ -246,7 +246,11 @@ _evas_object_text_horiz_advance_get(const Evas_Object *obj,
    EINA_INLIST_FOREACH(EINA_INLIST_GET(o->items), it)
      {
         adv += it->adv;
+        last_it = it;
      }
+
+   if (last_it && (last_it->w > last_it->adv))
+      adv += last_it->w - last_it->adv;
    return adv;
 }
 
@@ -531,8 +535,9 @@ _evas_object_text_layout(Evas_Object *obj, Evas_Object_Text *o, const Eina_Unico
 {
    EvasBiDiStrIndex *v_to_l = NULL;
    size_t pos, visual_pos;
-   int len = eina_unicode_strlen(text), par_len;
+   int len = eina_unicode_strlen(text);
 #ifdef BIDI_SUPPORT
+   int par_len = len;
    int *segment_idxs = NULL;
    if (o->bidi_delimiters)
       segment_idxs = evas_bidi_segment_idxs_get(text, o->bidi_delimiters);
@@ -543,7 +548,6 @@ _evas_object_text_layout(Evas_Object *obj, Evas_Object_Text *o, const Eina_Unico
 #endif
    visual_pos = pos = 0;
 
-   par_len = len;
    while (len > 0)
      {
         Evas_Font_Instance *script_fi = NULL;
