@@ -532,13 +532,16 @@ _evas_render_check_pending_objects(Eina_Array *pending_objects, Evas *e)
 
    for (i = 0; i < pending_objects->count; ++i)
      {
-        Evas_Object *obj;
+        Evas_Object *obj, *parent;
         int is_active, ok = 0;
 
         obj = eina_array_data_get(pending_objects, i);
-
         if (!obj->layer) goto clean_stuff;
 
+        parent = evas_object_smart_parent_get(obj);
+        if (parent && _evas_render_has_map(parent))
+          goto clean_stuff;
+
         evas_object_clip_recalc(obj);
         is_active = evas_object_is_active(obj);
 
@@ -606,59 +609,12 @@ pending_change(void *data, void *gdata __UNUSED__)
    if (obj->pre_render_done)
      {
         RD("  OBJ [%p] pending change %i -> 0, pre %i\n", obj, obj->changed, obj->pre_render_done);
-        obj->pre_render_done = 0;
-        //// FIXME: this wipes out changes
-        obj->changed = 0;
-        obj->changed_move_only = 0;
-        obj->changed_nomove = 0;
-        obj->changed_move = 0;
+        obj->pre_render_done = EINA_FALSE;
+        evas_object_change_reset(obj);
      }
    return obj->changed ? EINA_TRUE : EINA_FALSE;
 }
-/*
-   static void
-   unchange(Evas_Object *obj)
-   {
-   Evas_Object *obj2;
 
-   if (!obj->changed) return;
-   obj->changed = 0;
-   obj->changed_move_only = 0;
-   obj->changed_nomove = 0;
-   obj->changed_move = 0;
-   EINA_INLIST_FOREACH(evas_object_smart_members_get_direct(obj), obj2)
-   {
-   unchange(obj2);
-   }
-   }
-
-   static int
-   chlist(Evas_Object *obj, int i)
-   {
-   Evas_Object *obj2;
-   int j;
-   int ret = 0;
-
-   if (!obj->changed) return 0;
-   for (j = 0; j < i; j++) printf(" ");
-   printf("ch2 %p %s %i [%i %i %ix%i] v %i/%i [r%i] %p\n", obj,
-   obj->type,
-   obj->changed_move_only,
-   obj->cur.geometry.x,
-   obj->cur.geometry.y,
-   obj->cur.geometry.w,
-   obj->cur.geometry.h,
-   obj->cur.visible,
-   obj->prev.visible,
-   obj->restack,
-   obj->clip.clipees);
-   EINA_INLIST_FOREACH(evas_object_smart_members_get_direct(obj), obj2)
-   {
-   if (obj2->changed)
-   ret |= chlist(obj2, i + 1);
-   }
-   }
- */
 static Eina_Bool
 _evas_render_can_use_overlay(Evas *e, Evas_Object *obj)
 {
@@ -980,39 +936,25 @@ evas_render_mapped(Evas *e, Evas_Object *obj, void *context, void *surface,
                   if (!evas_object_is_visible(o2) &&
                       !evas_object_was_visible(o2))
                     {
-                       o2->changed = 0;
-                       o2->changed_move_only = 0;
-                       o2->changed_nomove = 0;
-                       o2->changed_move = 0;
+                       evas_object_change_reset(o2);
                        continue;
                     }
                   if (o2->changed)
                     {
-                       //                       chlist(o2, 0);
-                       changed = 1;
-                       o2->changed = 0;
-                       o2->changed_move_only = 0;
-                       o2->changed_nomove = 0;
-                       o2->changed_move = 0;
+                       changed = EINA_TRUE;
+                       evas_object_change_reset(o2);
                        break;
                     }
                }
-             //             unchange(obj);
-             obj->changed = 0;
-             obj->changed_move_only = 0;
-             obj->changed_nomove = 0;
-             obj->changed_move = 0;
+             if (obj->changed_color) changed = EINA_TRUE;
+             evas_object_change_reset(obj);
           }
-        else
+        else if (obj->changed)
           {
-             if (obj->changed)
-               {
-                  changed = 1;
-                  obj->changed = 0;
-                  obj->changed_move_only = 0;
-                  obj->changed_nomove = 0;
-                  obj->changed_move = 0;
-               }
+             if (((obj->changed_pchange) && (obj->changed_map)) ||
+                 (obj->changed_color))
+               changed = EINA_TRUE;
+             evas_object_change_reset(obj);
           }
 
         // clear surface before re-render
@@ -1139,15 +1081,19 @@ evas_render_mapped(Evas *e, Evas_Object *obj, void *context, void *surface,
                     }
                }
           }
-        if (surface == e->engine.data.output)
+//        if (surface == e->engine.data.output)
           e->engine.func->context_clip_clip(e->engine.data.output,
                                             e->engine.data.context,
                                             ecx, ecy, ecw, ech);
         if (obj->cur.cache.clip.visible)
-          obj->layer->evas->engine.func->image_map_draw
-             (e->engine.data.output, e->engine.data.context, surface,
-              obj->cur.map->surface, obj->cur.map->count, pts,
-              obj->cur.map->smooth, 0);
+          {
+             obj->layer->evas->engine.func->context_multiplier_unset
+               (e->engine.data.output, e->engine.data.context);
+             obj->layer->evas->engine.func->image_map_draw
+               (e->engine.data.output, e->engine.data.context, surface,
+                   obj->cur.map->surface, obj->cur.map->count, pts,
+                   obj->cur.map->smooth, 0);
+          }
         // FIXME: needs to cache these maps and
         // keep them only rendering updates
         //        obj->layer->evas->engine.func->image_map_surface_free
@@ -1360,6 +1306,8 @@ evas_render_updates_internal(Evas *e,
 
    RD("[--- RENDER EVAS (size: %ix%i)\n", e->viewport.w, e->viewport.h);
 
+   evas_event_callback_call(e, EVAS_CALLBACK_RENDER_PRE, NULL);
+   
    /* Check if the modified object mean recalculating every thing */
    if (!e->invalidate)
      _evas_render_check_pending_objects(&e->pending_objects, e);
@@ -1399,6 +1347,7 @@ evas_render_updates_internal(Evas *e,
         _evas_render_prev_cur_clip_cache_add(e, obj);
      }
    eina_array_clean(&e->restack_objects);
+
    /* phase 3. add exposes */
    EINA_LIST_FREE(e->damages, r)
      {
@@ -1406,7 +1355,20 @@ evas_render_updates_internal(Evas *e,
                                                 r->x, r->y, r->w, r->h);
         eina_rectangle_free(r);
      }
-   /* phase 4. output & viewport changes */
+
+   /* phase 4. framespace, output & viewport changes */
+   if (e->framespace.changed) 
+     {
+        int fx, fy, fw, fh;
+
+        fx = e->viewport.x - e->framespace.x;
+        fy = e->viewport.y - e->framespace.y;
+        fw = e->viewport.w + e->framespace.w;
+        fh = e->viewport.h + e->framespace.h;
+        e->engine.func->output_redraws_rect_add(e->engine.data.output, 
+                                                fx, fy, fw, fh);
+     }
+
    if (e->viewport.changed)
      {
         e->engine.func->output_redraws_rect_add(e->engine.data.output,
@@ -1431,6 +1393,7 @@ evas_render_updates_internal(Evas *e,
                                                 0, 0,
                                                 e->output.w, e->output.h);
      }
+
    /* phase 5. add obscures */
    EINA_LIST_FOREACH(e->obscures, ll, r)
      {
@@ -1483,6 +1446,12 @@ evas_render_updates_internal(Evas *e,
              off_x = cx - ux;
              off_y = cy - uy;
              /* build obscuring objects list (in order from bottom to top) */
+             if (alpha)
+               {
+                  e->engine.func->context_clip_set(e->engine.data.output,
+                                                   e->engine.data.context,
+                                                   ux + off_x, uy + off_y, uw, uh);
+               }
              for (i = 0; i < e->obscuring_objects.count; ++i)
                {
                   obj = (Evas_Object *)eina_array_data_get
@@ -1498,9 +1467,6 @@ evas_render_updates_internal(Evas *e,
                }
              if (alpha)
                {
-                  e->engine.func->context_clip_set(e->engine.data.output,
-                                                   e->engine.data.context,
-                                                   ux + off_x, uy + off_y, uw, uh);
                   e->engine.func->context_color_set(e->engine.data.output,
                                                     e->engine.data.context,
                                                     0, 0, 0, 0);
@@ -1531,7 +1497,7 @@ evas_render_updates_internal(Evas *e,
                       (obj->cur.visible) &&
                       (!obj->delete_me) &&
                       (obj->cur.cache.clip.visible) &&
-                      //		      (!obj->smart.smart) &&
+//		      (!obj->smart.smart) &&
                       ((obj->cur.color.a > 0 || obj->cur.render_op != EVAS_RENDER_BLEND)))
                     {
                        int x, y, w, h;
@@ -1562,13 +1528,9 @@ evas_render_updates_internal(Evas *e,
                             else
                               e->engine.func->context_mask_unset(e->engine.data.output,
                                                                  e->engine.data.context);
-                            if (obj->cur.clipper)
-                              e->engine.func->context_clip_set(e->engine.data.output,
-                                                               e->engine.data.context,
-                                                               x, y, w, h);
-                            else
-                              e->engine.func->context_clip_unset(e->engine.data.output,
-                                                                 e->engine.data.context);
+                            e->engine.func->context_clip_set(e->engine.data.output,
+                                                             e->engine.data.context,
+                                                             x, y, w, h);
 #if 1 /* FIXME: this can slow things down... figure out optimum... coverage */
                             for (j = offset; j < e->temporary_objects.count; ++j)
                               {
@@ -1579,9 +1541,6 @@ evas_render_updates_internal(Evas *e,
                                  _evas_render_cutout_add(e, obj2, off_x, off_y);
                               }
 #endif
-                            e->engine.func->context_clip_set(e->engine.data.output,
-                                                             e->engine.data.context,
-                                                             x, y, w, h);
                             clean_them |= evas_render_mapped(e, obj, e->engine.data.context,
                                                              surface, off_x, off_y, 0,
                                                              cx, cy, cw, ch
@@ -1622,22 +1581,16 @@ evas_render_updates_internal(Evas *e,
           {
              RD("    OBJ [%p] post... func1\n", obj);
              obj->func->render_post(obj);
-             obj->restack = 0;
-             obj->changed = 0;
-             obj->changed_move_only = 0;
-             obj->changed_nomove = 0;
-             obj->changed_move = 0;
+             obj->restack = EINA_FALSE;
+             evas_object_change_reset(obj);
           }
         else if ((obj->cur.map != obj->prev.map) ||
-                 (obj->cur.usemap != obj->prev.usemap))
+                 (obj->cur.usemap != obj->prev.usemap) || clean_them)
           {
              RD("    OBJ [%p] post... func2\n", obj);
              obj->func->render_post(obj);
-             obj->restack = 0;
-             obj->changed = 0;
-             obj->changed_move_only = 0;
-             obj->changed_nomove = 0;
-             obj->changed_move = 0;
+             obj->restack = EINA_FALSE;
+             evas_object_change_reset(obj);
           }
         /* moved to other pre-process phase 1
            if (obj->delete_me == 2)
@@ -1671,8 +1624,10 @@ evas_render_updates_internal(Evas *e,
    e->changed = 0;
    e->viewport.changed = 0;
    e->output.changed = 0;
+   e->framespace.changed = 0;
    e->invalidate = 0;
 
+   // always clean... lots of mem waste!
    /* If their are some object to restack or some object to delete,
     * it's useless to keep the render object list around. */
    if (clean_them)
@@ -1682,10 +1637,23 @@ evas_render_updates_internal(Evas *e,
         eina_array_clean(&e->restack_objects);
         eina_array_clean(&e->delete_objects);
         eina_array_clean(&e->obscuring_objects);
+        eina_array_clean(&e->temporary_objects);
+        eina_array_clean(&e->clip_changes);
+/* we should flush here and have a mempool system for this        
+        eina_array_flush(&e->active_objects);
+        eina_array_flush(&e->render_objects);
+        eina_array_flush(&e->restack_objects);
+        eina_array_flush(&e->delete_objects);
+        eina_array_flush(&e->obscuring_objects);
+        eina_array_flush(&e->temporary_objects);
+        eina_array_flush(&e->clip_changes);
+ */
         e->invalidate = 1;
      }
 
    evas_module_clean();
+   
+   evas_event_callback_call(e, EVAS_CALLBACK_RENDER_POST, NULL);
 
    RD("---]\n");
 
@@ -1755,11 +1723,14 @@ evas_render_idle_flush(Evas *e)
        (e->engine.data.output))
      e->engine.func->output_idle_flush(e->engine.data.output);
 
-   eina_array_flush(&e->delete_objects);
    eina_array_flush(&e->active_objects);
-   eina_array_flush(&e->restack_objects);
    eina_array_flush(&e->render_objects);
+   eina_array_flush(&e->restack_objects);
+   eina_array_flush(&e->delete_objects);
+   eina_array_flush(&e->obscuring_objects);
+   eina_array_flush(&e->temporary_objects);
    eina_array_flush(&e->clip_changes);
+   eina_array_flush(&e->temporary_objects);
 
    e->invalidate = 1;
 }
