@@ -16,6 +16,8 @@
 # include <memcheck.h>
 #endif
 
+//#define SURFDBG 1
+
 static Evas_Cache_Image * eci = NULL;
 static int                reference = 0;
 
@@ -145,7 +147,7 @@ _evas_common_rgba_image_new(void)
 #endif
 
    evas_common_rgba_image_scalecache_init(&im->cache_entry);
-   
+
    return &im->cache_entry;
 }
 
@@ -161,7 +163,7 @@ _evas_common_rgba_image_delete(Image_Entry *ie)
    LKD(im->cache_entry.ref_fq_del);
    eina_condition_free(&(im->cache_entry.cond_fq_del));
 # endif
-#endif   
+#endif
    evas_common_rgba_image_scalecache_shutdown(&im->cache_entry);
    if (ie->info.module) evas_module_unref((Evas_Module *)ie->info.module);
    /* memset the image to 0x99 because i recently saw a segv where an
@@ -173,13 +175,13 @@ _evas_common_rgba_image_delete(Image_Entry *ie)
 //   memset(im, 0x99, sizeof(im));
 #ifdef EVAS_CSERVE
    if (ie->data1) evas_cserve_image_free(ie);
-#endif   
+#endif
 /*
  * FIXME: This doesn't seem to be needed... But I'm not sure why.
  *	 -- nash
      {
         Filtered_Image *fi;
-        
+
         EINA_LIST_FREE(im->filtered, fi)
           {
              free(fi->key);
@@ -212,6 +214,30 @@ evas_common_rgba_image_free(Image_Entry *ie)
    _evas_common_rgba_image_delete(ie);
 }
 
+#ifdef SURFDBG
+static Eina_List *surfs = NULL;
+
+static void
+surf_debug(void)
+{
+   Eina_List *l;
+   Image_Entry *ie;
+   RGBA_Image *im;
+   int i = 0;
+   
+   printf("----SURFS----\n");
+   EINA_LIST_FOREACH(surfs, l, ie)
+     {
+        im = ie;
+        printf("%i - %p - %ix%i  [%s][%s]\n", 
+               i, im->image.data, ie->allocated.w, ie->allocated.h,
+               ie->file, ie->key
+              );
+        i++;
+     }
+}
+#endif
+
 EAPI void
 evas_common_rgba_image_unload(Image_Entry *ie)
 {
@@ -249,10 +275,15 @@ evas_common_rgba_image_unload(Image_Entry *ie)
 #endif
         return;
      }
-#endif   
-   
+#endif
+
    if (im->image.data && !im->image.no_free)
-     free(im->image.data);
+     {
+        free(im->image.data);
+#ifdef SURFDBG
+        surfs = eina_list_remove(surfs, ie);
+#endif        
+     }
    im->image.data = NULL;
    ie->allocated.w = 0;
    ie->allocated.h = 0;
@@ -260,24 +291,28 @@ evas_common_rgba_image_unload(Image_Entry *ie)
 #ifdef BUILD_ASYNC_PRELOAD
    ie->flags.preload_done = 0;
 #endif
+#ifdef SURFDBG
+   surf_debug();
+#endif   
 }
 
 void
 _evas_common_rgba_image_post_surface(Image_Entry *ie)
 {
 #ifdef HAVE_PIXMAN
-   RGBA_Image   *im = (RGBA_Image *) ie;
-   
+# ifdef PIXMAN_IMAGE   
+   RGBA_Image *im = (RGBA_Image *)ie;
+
    if (im->pixman.im) pixman_image_unref(im->pixman.im);
    if (im->cache_entry.flags.alpha)
      {
         im->pixman.im = pixman_image_create_bits
         (
-// FIXME: endianess determines this            
+// FIXME: endianess determines this
             PIXMAN_a8r8g8b8,
-//            PIXMAN_b8g8r8a8, 
+//            PIXMAN_b8g8r8a8,
             im->cache_entry.w, im->cache_entry.h,
-            im->image.data, 
+            im->image.data,
             im->cache_entry.w * 4
         );
      }
@@ -285,16 +320,19 @@ _evas_common_rgba_image_post_surface(Image_Entry *ie)
      {
         im->pixman.im = pixman_image_create_bits
         (
-// FIXME: endianess determines this            
+// FIXME: endianess determines this
             PIXMAN_x8r8g8b8,
 //            PIXMAN_b8g8r8x8,
             im->cache_entry.w, im->cache_entry.h,
-            im->image.data, 
+            im->image.data,
             im->cache_entry.w * 4
         );
      }
+# else
+   (void)ie;
+# endif
 #else
-   ie = NULL;
+   (void)ie;
 #endif
 }
 
@@ -306,7 +344,7 @@ _evas_common_rgba_image_surface_alloc(Image_Entry *ie, unsigned int w, unsigned
 
 #ifdef EVAS_CSERVE
    if (ie->data1) return 0;
-#endif   
+#endif
    if (im->image.no_free) return 0;
 
    if (im->flags & RGBA_IMAGE_ALPHA_ONLY)
@@ -314,10 +352,20 @@ _evas_common_rgba_image_surface_alloc(Image_Entry *ie, unsigned int w, unsigned
    else
      siz = w * h * sizeof(DATA32);
 
-   if (im->image.data) free(im->image.data);
+   if (im->image.data)
+     {
+        free(im->image.data);
+#ifdef SURFDBG
+        surfs = eina_list_remove(surfs, ie);
+#endif        
+     }
    im->image.data = malloc(siz);
    if (!im->image.data) return -1;
-
+   ie->allocated.w = w;
+   ie->allocated.h = h;
+#ifdef SURFDBG
+   surfs = eina_list_append(surfs, ie);
+#endif   
 #ifdef HAVE_VALGRIND
 # ifdef VALGRIND_MAKE_READABLE
    VALGRIND_MAKE_READABLE(im->image.data, siz);
@@ -328,7 +376,9 @@ _evas_common_rgba_image_surface_alloc(Image_Entry *ie, unsigned int w, unsigned
 # endif
 #endif
    _evas_common_rgba_image_post_surface(ie);
-   
+#ifdef SURFDBG
+   surf_debug();
+#endif
    return 0;
 }
 
@@ -338,12 +388,14 @@ _evas_common_rgba_image_surface_delete(Image_Entry *ie)
    RGBA_Image   *im = (RGBA_Image *) ie;
 
 #ifdef HAVE_PIXMAN
+# ifdef PIXMAN_IMAGE   
    if (im->pixman.im)
      {
         pixman_image_unref(im->pixman.im);
         im->pixman.im = NULL;
      }
-#endif   
+# endif   
+#endif
    if (ie->file)
      DBG("unload: [%p] %s %s", ie, ie->file, ie->key);
    if ((im->cs.data) && (im->image.data))
@@ -360,11 +412,16 @@ _evas_common_rgba_image_surface_delete(Image_Entry *ie)
    im->cs.data = NULL;
 
    if (im->image.data && !im->image.no_free)
-     free(im->image.data);
+     {
+        free(im->image.data);
+#ifdef SURFDBG
+        surfs = eina_list_remove(surfs, ie);
+#endif        
+     }
 #ifdef EVAS_CSERVE
    else if (ie->data1)
      evas_cserve_image_free(ie);
-#endif   
+#endif
 
    im->image.data = NULL;
    ie->allocated.w = 0;
@@ -374,6 +431,9 @@ _evas_common_rgba_image_surface_delete(Image_Entry *ie)
 #endif
    ie->flags.loaded = 0;
    evas_common_rgba_image_scalecache_dirty(&im->cache_entry);
+#ifdef SURFDBG
+   surf_debug();
+#endif   
 }
 
 static void
@@ -391,7 +451,7 @@ _evas_common_rgba_image_dirty_region(Image_Entry* ie, unsigned int x __UNUSED__,
 
 #ifdef EVAS_CSERVE
    if (ie->data1) evas_cserve_image_free(ie);
-#endif   
+#endif
    im->flags |= RGBA_IMAGE_IS_DIRTY;
    evas_common_rgba_image_scalecache_dirty(&im->cache_entry);
 }
@@ -411,13 +471,13 @@ _evas_common_rgba_image_dirty(Image_Entry *ie_dst, const Image_Entry *ie_src)
      {
 #ifdef EVAS_CSERVE
         if (ie_src->data1) evas_cserve_image_free((Image_Entry*) ie_src);
-#endif        
+#endif
         return 1;
      }
 
 #ifdef EVAS_CSERVE
    if (ie_src->data1) evas_cserve_image_free((Image_Entry*) ie_src);
-#endif   
+#endif
    evas_common_image_colorspace_normalize(src);
    evas_common_image_colorspace_normalize(dst);
 /*    evas_common_blit_rectangle(src, dst, 0, 0, src->cache_entry.w, src->cache_entry.h, 0, 0); */
@@ -431,18 +491,18 @@ _evas_common_rgba_image_ram_usage(Image_Entry *ie)
 {
    RGBA_Image *im = (RGBA_Image *)ie;
    int size = sizeof(struct _RGBA_Image);
-   
+
    if (ie->cache_key) size += strlen(ie->cache_key);
    if (ie->file) size += strlen(ie->file);
    if (ie->key) size += strlen(ie->key);
-   
+
    if (im->image.data)
      {
 #ifdef EVAS_CSERVE
         if ((!im->image.no_free) || (ie->data1))
 #else
         if ((!im->image.no_free))
-#endif          
+#endif
           size += im->cache_entry.w * im->cache_entry.h * sizeof(DATA32);
      }
    size += evas_common_rgba_image_scalecache_usage_get(&im->cache_entry);
@@ -590,8 +650,16 @@ evas_common_image_colorspace_normalize(RGBA_Image *im)
 	  {
 #ifdef EVAS_CSERVE
              if (((Image_Entry *)im)->data1) evas_cserve_image_free(&im->cache_entry);
-#endif             
-	     if (!im->image.no_free) free(im->image.data);
+#endif
+	     if (!im->image.no_free)
+               {
+                  free(im->image.data);
+#ifdef SURFDBG
+                  surfs = eina_list_remove(surfs, im);
+#endif                  
+                  ((Image_Entry *)im)->allocated.w = 0;
+                  ((Image_Entry *)im)->allocated.h = 0;
+               }
 	     im->image.data = im->cs.data;
 	     im->cs.no_free = im->image.no_free;
 	  }
@@ -628,6 +696,9 @@ evas_common_image_colorspace_normalize(RGBA_Image *im)
 	break;
      }
    im->cs.dirty = 0;
+#ifdef SURFDBG
+   surf_debug();
+#endif   
 }
 
 EAPI void
@@ -635,6 +706,16 @@ evas_common_image_colorspace_dirty(RGBA_Image *im)
 {
    im->cs.dirty = 1;
    evas_common_rgba_image_scalecache_dirty(&im->cache_entry);
+#ifdef HAVE_PIXMAN
+# ifdef PIXMAN_IMAGE   
+   if (im->pixman.im)
+     {
+        pixman_image_unref(im->pixman.im);
+        im->pixman.im = NULL;
+     }
+   _evas_common_rgba_image_post_surface((Image_Entry *)im);
+# endif   
+#endif
 }
 
 EAPI void
